import type { AnchorHTMLAttributes, ReactNode } from "react";
export interface SkipToMainContentProps extends AnchorHTMLAttributes<HTMLAnchorElement> {
    /**
     * An id to use for the link.
     */
    id?: string;
    /**
     * The id to use for the `<main>` content that should be focused once this
     * link is clicked.
     */
    mainId: string;
    /**
     * The children to display once the link has been keyboard focused.
     */
    children?: ReactNode;
    /**
     * Boolean if the skip to main content link should be unstyled so that you can
     * provide your own styles. This is just helpful if you are using this
     * component in a multiple places and don't want to keep overriding the
     * default styles each time.
     *
     * Note: there will still be the "base" link styles, font size, and z-index.
     * The `$rmd-link-skip-styles` and `$rmd-link-skip-active-styles` will not be
     * applied.
     */
    unstyled?: boolean;
}
/**
 * This component allows you to create a screen-reader only/keyboard focusable
 * only link that allows a user to skip to the main content of the page. This is
 * extremely useful when you have a lot of navigation items that must be tabbed
 * through before the main content can be focused and this component should
 * normally be the first focusable element on your page.
 */
export declare const SkipToMainContent: import("react").ForwardRefExoticComponent<SkipToMainContentProps & import("react").RefAttributes<HTMLAnchorElement>>;
